@@ -1,13 +1,15 @@
 /*
  * Java-Gnome Bindings Library
  *
- * Copyright 1998-2002 the Java-Gnome Team, all rights reserved.
+ * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
  *
  * The Java-Gnome bindings library is free software distributed under
  * the terms of the GNU Library General Public License version 2.
  */
+
 package org.gnu.gnome;
 
+import org.gnu.glib.Handle;
 import org.gnu.gtk.Dialog;
 
 /**
@@ -23,8 +25,7 @@ public class PasswordDialog extends Dialog {
 	 * @param readonlyUsername Is the username editable?
 	 */
 	public PasswordDialog(String title, String message, String username, String password, boolean readonlyUsername) {
-		setHandle(gnome_password_dialog_new(title, message, username, password, readonlyUsername));
-		initializeEventHandlers();
+		super(gnome_password_dialog_new(title, message, username, password, readonlyUsername));
 	}
 	
 	public boolean runAndBlock() {
@@ -59,21 +60,22 @@ public class PasswordDialog extends Dialog {
 		return gnome_password_dialog_get_remember(getHandle());
 	}
 	
-	/****************************************
-	 * BEGINNING OF JNI CODE
-	 ****************************************/
+	public void setShowUserpassButtons(boolean show) {
+		gnome_password_dialog_set_show_userpass_buttons(getHandle(), show);
+	}
+	
+
 	native static final protected int gnome_password_dialog_get_type();
-	native static final protected int gnome_password_dialog_new(String title, String message, String username, String password, boolean readonlyUsername);
-	native static final protected boolean gnome_password_dialog_run_and_block(int dialog);
-	native static final protected void gnome_password_dialog_set_username(int dialog, String username);
-	native static final protected void gnome_password_dialog_set_password(int dialog, String password);
-	native static final protected void gnome_password_dialog_set_readonly_username(int dialog, boolean readonly);
-	native static final protected void gnome_password_dialog_set_remember(int dialog, boolean remember);
-	native static final protected String gnome_password_dialog_get_username(int dialog);
-	native static final protected String gnome_password_dialog_get_password(int dialog);
-	native static final protected boolean gnome_password_dialog_get_remember(int dialog);
-	/****************************************
-	 * END OF JNI CODE
-	 ****************************************/
+	native static final protected Handle gnome_password_dialog_new(String title, String message, String username, String password, boolean readonlyUsername);
+	native static final protected boolean gnome_password_dialog_run_and_block(Handle dialog);
+	native static final protected void gnome_password_dialog_set_username(Handle dialog, String username);
+	native static final protected void gnome_password_dialog_set_password(Handle dialog, String password);
+	native static final protected void gnome_password_dialog_set_readonly_username(Handle dialog, boolean readonly);
+	native static final protected void gnome_password_dialog_set_remember(Handle dialog, boolean remember);
+	native static final protected void gnome_password_dialog_set_show_userpass_buttons(Handle dialog, boolean show);
+	native static final protected String gnome_password_dialog_get_username(Handle dialog);
+	native static final protected String gnome_password_dialog_get_password(Handle dialog);
+	native static final protected boolean gnome_password_dialog_get_remember(Handle dialog);
+
 	
 }
